==> kdesdk_4.6.2.orig.tar.bz2: kdesdk-4.6.2/okteta/kasten/core/io/filesystem/bytearrayrawfilewritethread.cpp <==
/*
    This file is part of the Okteta Kasten module, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytearrayrawfilewritethread.h"

// lib
#include "bytearraydocument.h"
// Okteta core
#include <piecetablebytearraymodel.h>
// Qt
#include <QtCore/QDataStream>
#include <QtCore/QFile>


namespace Kasten
{

void ByteArrayRawFileWriteThread::run()
{
    Okteta::PieceTableByteArrayModel *byteArray = qobject_cast<Okteta::PieceTableByteArrayModel*>( mDocument->content() );

    QDataStream outStream( mFile );

    //TODO: this was
//     outStream.writeRawData( byteArray->data(), byteArray->size() );
    // make it quicker again by writing spans -> spaniterator

    for( int i = 0; i<byteArray->size(); ++i )
    {
        const Okteta::Byte byte = byteArray->byte(i);
        outStream.writeRawData( reinterpret_cast<const char*>(&byte), 1 );
    }

    byteArray->setModified( false );

    mSuccess = ( outStream.status() == QDataStream::Ok );

    emit documentWritten( mSuccess );
}

ByteArrayRawFileWriteThread::~ByteArrayRawFileWriteThread() {}

}

==> kdesdk-4.7.3.tar.bz2: kdesdk-4.7.3/okteta/kasten/core/io/filesystem/bytearrayrawfilewritethread.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytearrayrawfilewritethread.h"

// lib
#include "bytearraydocument.h"
// Okteta core
#include <piecetablebytearraymodel.h>
// Qt
#include <QtCore/QDataStream>
#include <QtCore/QFile>


namespace Kasten
{

void ByteArrayRawFileWriteThread::run()
{
    Okteta::PieceTableByteArrayModel *byteArray = qobject_cast<Okteta::PieceTableByteArrayModel*>( mDocument->content() );

    QDataStream outStream( mFile );

    //TODO: this was
//     outStream.writeRawData( byteArray->data(), byteArray->size() );
    // make it quicker again by writing spans -> spaniterator

    for( int i = 0; i<byteArray->size(); ++i )
    {
        const Okteta::Byte byte = byteArray->byte(i);
        outStream.writeRawData( reinterpret_cast<const char*>(&byte), 1 );
    }

    byteArray->setModified( false );

    mSuccess = ( outStream.status() == QDataStream::Ok );

    emit documentWritten( mSuccess );
}

ByteArrayRawFileWriteThread::~ByteArrayRawFileWriteThread() {}

}
